@@ -1,15 +1,18 @@
 import time
 import requests
 
+REQUEST_TIMEOUT = 20
+
 class _StatsigNetwork:
 
     __RETRY_CODES = [408, 500, 502, 503, 504, 522, 524, 599]
 
-    def __init__(self, sdkKey, api):
+    def __init__(self, sdkKey, api, timeout=None):
         self.__sdk_key = sdkKey
         if not api.endswith("/"):
             api = api + "/"
         self.__api = api
+        self.__timeout = timeout or REQUEST_TIMEOUT
     
     def post_request(self, endpoint, payload):
         headers = {
@@ -18,7 +21,7 @@ class _StatsigNetwork:
             'STATSIG-CLIENT-TIME': str(round(time.time() * 1000)),
         }
         try:
-            response = requests.post(self.__api + endpoint, json=payload, headers=headers)
+            response = requests.post(self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
             if response.status_code == 200:
                 data = response.json()
                 if data:
@@ -34,10 +37,10 @@ class _StatsigNetwork:
             'STATSIG-CLIENT-TIME': str(round(time.time() * 1000)),
         }
         try:
-            response = requests.post(self.__api + endpoint, json=payload, headers=headers)
+            response = requests.post(self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
             if response.status_code in self.__RETRY_CODES:
                 return payload
             else:
                 return None
         except Exception as e:
-            return None
\ No newline at end of file
+            return None
